@@ -21,21 +21,21 @@ impl IpMapSynDataset {
         return IpMapSynDataset { dataset, comm };
     }
     /// Used to add IP with custom information like tags.
-    pub fn insert(&mut self, ip: SiemIp, data: Cow<'static, str>) {
+    pub fn insert(&self, ip: SiemIp, data: Cow<'static, str>) {
         // Todo: improve with local cache to send retries
         match self.comm.try_send(UpdateIpMap::Add((ip, data))) {
             Ok(_) => {}
             Err(_) => {}
         };
     }
-    pub fn remove(&mut self, ip: SiemIp) {
+    pub fn remove(&self, ip: SiemIp) {
         // Todo: improve with local cache to send retries
         match self.comm.try_send(UpdateIpMap::Remove(ip)) {
             Ok(_) => {}
             Err(_) => {}
         };
     }
-    pub fn update(&mut self, data : IpMapDataset) {
+    pub fn update(&self, data : IpMapDataset) {
         // Todo: improve with local cache to send retries
         match self.comm.try_send(UpdateIpMap::Replace(data)) {
             Ok(_) => {}
